(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10840,        396]*)
(*NotebookOutlinePosition[     29623,       1081]*)
(*  CellTagsIndexPosition[     29579,       1077]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Tutorial 10:  ",
  StyleBox["Calculus",
    FontSlant->"Italic"]
}], "Title",
  TextAlignment->Left,
  FontSize->30],

Cell["by R. Dover, IMSA", "Subtitle",
  TextAlignment->Left,
  FontSize->14],

Cell[TextData[{
  "\tNaturally, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is pretty good at calculus.  We'll begin with limits.  For the most part, \
the examples are self-explanatory.  Create your own problems and examples as \
you go.  (Note that this notebook is optional.)"
}], "Text"],

Cell[CellGroupData[{

Cell["Limits", "Section"],

Cell[BoxData[
    \(Limit[Sin[x]\/x, \ x \[Rule] 0]\)], "Input"],

Cell[BoxData[
    \(Limit[\(2  x\^3 - 4  x\)\/\(x\^3 + 1\), \ x \[Rule] \ \[Infinity]]\)], 
  "Input"],

Cell[TextData[{
  "\tRemember that one can use the word \"Infinity\" instead of the symbol.  \
(This is not to suggest that's better, but it is to remind you that it's an \
option.)  \n\tThe notation for one-sided limits may be a little confusing, \
given the usual ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \(a\^+\)\)]],
  "or ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \(a\^-\)\)]],
  "notation seen in books and hand-written work.  When we write ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \(a\^+\)\)]],
  ", x is coming from the right, going left. Hence, it is moving in a \
negative direction and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses \"Direction\[Rule] -1.\"  Similarly, for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \(a\^-\)\)]],
  ", x is coming from the left, moving in a positive direction, so we use \
\"Direction\[Rule] 1.\""
}], "Text"],

Cell[BoxData[
    \(Limit[1/x, \ x \[Rule] 0, \ Direction \[Rule] 1]\)], "Input"],

Cell[BoxData[
    \(Limit[1/x, \ x \[Rule] 0, \ Direction \[Rule] \(-1\)]\)], "Input"],

Cell["Here's a different type - which should be recognizable.", "Text"],

Cell[BoxData[
    \(Limit[\(Tan[x + h] - Tan[x]\)\/h, \ h \[Rule] 0]\)], "Input"],

Cell["\<\
Though this is certainly accurate, see the next section for more \
direct methods.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Derivatives", "Section"],

Cell[TextData[{
  "\tBe sure to indicate the variable in each case.  (Note that this is one \
of the few cases where ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not require the full English word for the command.)"
}], "Text"],

Cell[BoxData[
    \(D[x\ Log[x], \ x]\)], "Input"],

Cell["\<\
Find the next derivative and then simplify the result to see the \
more familiar form.\
\>", "Text"],

Cell[BoxData[
    \(D[f[x]/g[x], \ x]\)], "Input"],

Cell[BoxData[
    \(D[\(-\((1/2)\)\)\ g\ t\^2 + v\_0\ t\  + \ s\_0, \ t]\)], "Input"],

Cell[TextData[{
  "To find the third derivative, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(d\^3\) y\)\/dx\^3\)]],
  ", the coding at the end changes as follows."
}], "Text"],

Cell[BoxData[
    \(D[Tan[x], \ {x, \ 3}]\)], "Input"],

Cell["\<\
Alternatively, once can define a function first and then use more \
standard notation.\
\>", "Text"],

Cell[BoxData[
    \(f[x_] := Sin[Sin[Sin[x]]]\)], "Input"],

Cell[BoxData[
    \(\(f'\)[x]\)], "Input"],

Cell[BoxData[
    \(\(\(f'\)'\)[x]\)], "Input"],

Cell[TextData[{
  "On the palette, for the familiar derivative in single-variable calculus, \
use ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_\[Placeholder]\ \[Placeholder]\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcTan[x]\)], "Input"],

Cell[TextData[{
  "For multivariable functions, use ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[PartialD]\_\(\[Placeholder], \[Placeholder]\)\[Placeholder]\)]],
  ".  Note that the parentheses are necessary."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_\(x, y\)\((x\^3\ y\^4)\)\)], "Input"],

Cell[CellGroupData[{

Cell["Implicit functions", "Subsection"],

Cell["\<\
\tImplicitly-defined functions require some special care.  First, \
we'll name our equation.\
\>", "Text"],

Cell[BoxData[
    \(equat1\  = \ x\^3 - \ 4\ x\ y\  + \ y\^2 == 12\)], "Input"],

Cell[TextData[{
  "We can't take a derivative with respect to x yet, since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " would interpret y as a constant.  We must first express y as f[x]."
}], "Text"],

Cell[BoxData[
    \(equat1 /. y \[Rule] f[x]\)], "Input"],

Cell["Then differentiate and solve for f'[x].", "Text"],

Cell[BoxData[
    \(D[%, x]\)], "Input"],

Cell[BoxData[
    \(Solve[%, \ \(f'\)[x]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["A max-min problem", "Subsection"],

Cell[TextData[
"\tConsider the function y = cos(x) over the interval (-\[Pi]/2, \[Pi]/2).  \
Find the area of the largest rectangle which may be constructed with two \
vertices on the x-axis and the other two vertices on the graph of the \
function."], "Text"],

Cell["\<\
First, we'll draw a picture to help understand the problem a little \
better, beginning with the graph of cos(x).\
\>", "Text"],

Cell[BoxData[
    \(grcosx\  = \ Plot[Cos[x], \ {x, \ \(-2\), \ 2}]\)], "Input"],

Cell["\<\
The next group of commands give something new.  We construct a \
typical rectangle and then show the rectangle and the graph together.\
\>", 
  "Text"],

Cell[BoxData[
    \(Needs["\<Graphics`Master`\>"]; \n
    rect\  = \ {GrayLevel[.5], Rectangle[{\(-1.1\), 0}, {1.1, \ Cos[1.1]}]}; 
    \nShow[{Graphics[rect], \ grcosx}, \ Axes\  -> \ True]\)], "Input"],

Cell["\<\
We now define the area function, where the base is 2x and the \
height is Cos[x].\
\>", "Text"],

Cell[BoxData[
    \(areaofrect[x_] := 2  x\ Cos[x]\)], "Input"],

Cell["\<\
Find the derivative, and solve for the stationary point. Here, the \
FindRoot command will be appropriate.\
\>", "Text"],

Cell[BoxData[
    \(FindRoot[\(areaofrect'\)[x] == 0, \ {x, \ 1}]\)], "Input"],

Cell["Substitute this value of x to find the area.", "Text"],

Cell[BoxData[
    \(areaofrect[x] /. %\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrals", "Section"],

Cell[BoxData[
    \(Integrate[x^3\ Cos[x], \ x]\)], "Input"],

Cell[BoxData[
    \(\[Integral]\(1\/\(x\^4 + 1\)\) \[DifferentialD]x\)], "Input"],

Cell[TextData[{
  "As before, the command may be entered in the \"old\" way or using the \
palette.  As you would expect, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will integrate lots of functions, but there are some which can't be done. \
 It's not that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can't handle them; they just don't have elementary antiderivative \
formulas.  Check these out."
}], "Text"],

Cell[BoxData[
    \(\[Integral]Sin[Sin[x]] \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(\[Integral]Sin[t]/t \[DifferentialD]t\)], "Input"],

Cell["\<\
Definite integrals may be done exactly or approximately, with \
choices of notation.\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_3\%5\(\( x + 1\)\/\(x\^2 - 4\)\) \[DifferentialD]x\)], 
  "Input"],

Cell[BoxData[
    \(Integrate[\((x + \ 1)\)/\((x^2 - 4)\), \ {x, \ 3, \ 5}]\)], "Input"],

Cell[BoxData[
    \(NIntegrate[\((x + \ 1)\)/\((x^2 - 4)\), \ {x, \ 3, \ 5}]\)], "Input"],

Cell[TextData[{
  "Note that if",
  StyleBox["  N[  ] ",
    FontWeight->"Bold"],
  " is used around the symbolic integral sign, then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " first tries to integrate exactly if possible.  Using NIntegrate may be \
faster.  \n\tImproper integrals may be done as well. (Note: Sometimes \"\
\[Infinity]\" shows as a small black rectangle.)"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_1\%\[Infinity] 1/x\^3 \[DifferentialD]x\)], "Input"],

Cell["\<\
Or perhaps we should consider the Fundamental Theorem and look at a \
plot and a derivative  related to this.\
\>", "Text"],

Cell[BoxData[
    \(Plot[\[Integral]\_0\%x Cos[t] \[DifferentialD]t, \ {x, \ 0, \ 2  \[Pi]}]
      \)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ \(\[Integral]\_0\%x Cos[t] \[DifferentialD]t\)\)], 
  "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Series", "Section"],

Cell[TextData[{
  "The Taylor series in x about a = 0 of degree 6 for  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^x\)]],
  " is found by the following coding."
}], "Text"],

Cell[BoxData[
    \(Series[\[ExponentialE]\^x, \ {x, \ 0, \ 6}]\)], "Input"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`O[x]\^7\)]],
  "represents the error or remainder.  To eliminate this (before graphing or \
using the polynomial in some other way), use the \"Normal\" command."
}], "Text"],

Cell[BoxData[
    \(Normal[%]\)], "Input"],

Cell["\<\
Find several terms of the series for Sin[x].  Plot the polynomial \
and Sin[x] together in different colors.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Differential equations", "Section"],

Cell["\<\
As with implicit derivatives, be sure to indicate that y is a \
function of x by using y[x].  To solve y'' - y' - 6y = x, execute the \
following.\
\>", "Text"],

Cell[BoxData[
    \(DSolve[\(\(y'\)'\)[x] - \(y'\)[x] - 6  y[x] == x, \ y[x], \ x]\)], 
  "Input"]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowSize->{520, 365},
WindowMargins->{{8, Automatic}, {Automatic, 9}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.100008, 0.6]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[0.820005, 0.949996, 0.949996]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 135, 6, 46, "Title"],
Cell[1847, 57, 76, 2, 34, "Subtitle"],
Cell[1926, 61, 306, 7, 59, "Text"],

Cell[CellGroupData[{
Cell[2257, 72, 25, 0, 53, "Section"],
Cell[2285, 74, 64, 1, 62, "Input"],
Cell[2352, 77, 102, 2, 64, "Input"],
Cell[2457, 81, 920, 22, 135, "Text"],
Cell[3380, 105, 81, 1, 47, "Input"],
Cell[3464, 108, 86, 1, 47, "Input"],
Cell[3553, 111, 71, 0, 26, "Text"],
Cell[3627, 113, 81, 1, 62, "Input"],
Cell[3711, 116, 106, 3, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3854, 124, 30, 0, 33, "Section"],
Cell[3887, 126, 245, 6, 44, "Text"],
Cell[4135, 134, 50, 1, 47, "Input"],
Cell[4188, 137, 110, 3, 26, "Text"],
Cell[4301, 142, 50, 1, 47, "Input"],
Cell[4354, 145, 85, 1, 51, "Input"],
Cell[4442, 148, 179, 5, 33, "Text"],
Cell[4624, 155, 54, 1, 47, "Input"],
Cell[4681, 158, 110, 3, 26, "Text"],
Cell[4794, 163, 58, 1, 47, "Input"],
Cell[4855, 166, 42, 1, 47, "Input"],
Cell[4900, 169, 47, 1, 47, "Input"],
Cell[4950, 172, 208, 6, 26, "Text"],
Cell[5161, 180, 58, 1, 47, "Input"],
Cell[5222, 183, 229, 6, 26, "Text"],
Cell[5454, 191, 70, 1, 51, "Input"],

Cell[CellGroupData[{
Cell[5549, 196, 40, 0, 43, "Subsection"],
Cell[5592, 198, 116, 3, 30, "Text"],
Cell[5711, 203, 79, 1, 29, "Input"],
Cell[5793, 206, 213, 5, 47, "Text"],
Cell[6009, 213, 57, 1, 27, "Input"],
Cell[6069, 216, 55, 0, 30, "Text"],
Cell[6127, 218, 40, 1, 27, "Input"],
Cell[6170, 221, 54, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6261, 227, 39, 0, 27, "Subsection"],
Cell[6303, 229, 260, 4, 62, "Text"],
Cell[6566, 235, 137, 3, 46, "Text"],
Cell[6706, 240, 80, 1, 27, "Input"],
Cell[6789, 243, 161, 4, 46, "Text"],
Cell[6953, 249, 203, 3, 75, "Input"],
Cell[7159, 254, 105, 3, 30, "Text"],
Cell[7267, 259, 63, 1, 27, "Input"],
Cell[7333, 262, 130, 3, 46, "Text"],
Cell[7466, 267, 78, 1, 27, "Input"],
Cell[7547, 270, 60, 0, 30, "Text"],
Cell[7610, 272, 51, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7710, 279, 28, 0, 33, "Section"],
Cell[7741, 281, 60, 1, 47, "Input"],
Cell[7804, 284, 81, 1, 62, "Input"],
Cell[7888, 287, 439, 11, 76, "Text"],
Cell[8330, 300, 73, 1, 60, "Input"],
Cell[8406, 303, 70, 1, 60, "Input"],
Cell[8479, 306, 108, 3, 26, "Text"],
Cell[8590, 311, 99, 2, 64, "Input"],
Cell[8692, 315, 88, 1, 47, "Input"],
Cell[8783, 318, 89, 1, 47, "Input"],
Cell[8875, 321, 401, 10, 87, "Text"],
Cell[9279, 333, 85, 1, 62, "Input"],
Cell[9367, 336, 133, 3, 42, "Text"],
Cell[9503, 341, 112, 2, 62, "Input"],
Cell[9618, 345, 98, 2, 62, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9753, 352, 25, 0, 33, "Section"],
Cell[9781, 354, 189, 5, 26, "Text"],
Cell[9973, 361, 76, 1, 47, "Input"],
Cell[10052, 364, 240, 6, 43, "Text"],
Cell[10295, 372, 42, 1, 47, "Input"],
Cell[10340, 375, 132, 3, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10509, 383, 41, 0, 33, "Section"],
Cell[10553, 385, 170, 4, 42, "Text"],
Cell[10726, 391, 98, 2, 47, "Input"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

