(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9081,        281]*)
(*NotebookOutlinePosition[     28216,        980]*)
(*  CellTagsIndexPosition[     28086,        972]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Welcome to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "!\n",
  StyleBox["an introduction to version 3.0",
    FontSize->24]
}], "Text",
  TextAlignment->Center,
  FontSize->36,
  FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
  "Tutorial 1:  ",
  StyleBox["Getting Started",
    FontSlant->"Italic"]
}], "Title",
  FontSize->24],

Cell[TextData[StyleBox[
"by Ruth Dover, Illinois Mathematics and Science Academy",
  FontSize->18]], "Subtitle",
  TextAlignment->Left,
  FontSize->18],

Cell[TextData[{
  "\tYou have just opened a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \"notebook.\"  This one is designed to give an introduction to some of \
the many features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 - the mathematics as well as the workings of the program.  Many of \
these will be seen again in more detail in later notebooks.\n\tWhat you see \
now is similar to an outline form, with section headings shown.  Below this \
paragraph, find the line with \"Numbers\" in bold print.  (\"Numbers\" is a \
\"section\" heading.)  Move the cursor to the far right of that line to the \
vertical bar with the little triangle at the bottom.    The cursor will \
change to a vertical segment with an arrow. Double click on this bar with the \
triangle to open the section.  Try opening and closing the section a couple \
of times.  Then follow the directions."
}], "Text"],

Cell[CellGroupData[{

Cell["Numbers", "Section"],

Cell[TextData[{
  "\tFind the line below with the \"",
  Cell[BoxData[
      \(TraditionalForm\`\@20\)]],
  "\" in bold print.  Move the cursor to this \"input line\" so that it \
appears as a vertical I-bar and click.  Then press \"Shift-Return\" or simply \
\"Enter\" - a key on the far right of most keyboards - to \"execute\" this \
command line.  (A simple \"Return\" only moves the cursor to the next line, \
just as it does in a word processor.)"
}], "Text"],

Cell[BoxData[
    \(\@20\)], "Input"],

Cell[TextData[{
  "\tOK, so ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can simplify.  Also, if that took a while, that's because another program \
called the \"",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel\" has to be loaded the first time.  Let's try another one.  \
(Again, press \"Shift-Return\" or \"Enter\" to execute the command.)"
}], "Text"],

Cell[BoxData[
    \(\@10\)], "Input"],

Cell[TextData[{
  "\tWell...that was exciting.  The number is exact, so ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " left it alone.  Let's make a slight change.  Again, put the cursor in the \
line below and execute the \"input cell\".  (A \"cell\" may be just about \
anything - a command, text, or a section header such as \"Numbers\" above.  \
\"Input cells\" are recognizable by the bold text and may be \"executed.\"  \
Each cell is shown individually and in groups by the brackets to the far \
right.)"
}], "Text"],

Cell[BoxData[
    \(N[\@10]\)], "Input"],

Cell[TextData[{
  "\tAt least it did something.  How about a few more decimal places?  Edit \
the line above so it reads:  ",
  StyleBox["N[",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\@10\)],
    FontWeight->"Bold"],
  StyleBox[", 50]",
    FontWeight->"Bold"],
  "  by typing \", 50\" after the square root but before the closing bracket. \
 (Don't type the quotation marks!)  Execute the cell.  What happened?  Then \
execute the cell below.  Note the different expression for the square root."
}], "Text"],

Cell[BoxData[
    \(Sqrt[48]\)], "Input"],

Cell[TextData[{
  "\tAgain, at least it simplifies, but we'll ask for a numerical \
approximation.  We could do this by editing the line above, but we'll learn \
another method.  Create a new cell by moving the cursor below this paragraph \
so that the cursor changes to a horizontal I-bar.  Click.  A horizontal line \
should appear.  Then start typing \"N[%]\" (without the quotation marks) and \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will make room for you.  Note that the \" % \" refers to the last output. \
 (Using \"In's\" and \"Out's\" which are created by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allows one to refer to previous work as well.)"
}], "Text",
  CellTags->"newcell"],

Cell["\<\
\tLet's try a couple of other things.  Sine and tangent are \
built-in functions. As such, they must be capitalized, and their arguments \
are in square brackets.  Execute each of the two cells below.  Find numerical \
approximations.  Or edit the expressions.  (Create your own if you wish, but \
we'll come back to that later.)\
\>", "Text"],

Cell[BoxData[
    \(Sin[\[Pi]\/3] + \ Tan[\(5  \[Pi]\)\/6]\)], "Input"],

Cell[BoxData[
    \(\[Sum]\+\(k = 1\)\%100 1\/k\^2\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolics", "Section",
  CellTags->"symbolic"],

Cell["\<\
Execute each of the following cells below (separately) to see a bit \
of simplification.\
\>", "Text"],

Cell[BoxData[
    \(3  x\^4 - 6  x\^\(2\ \) + \ 5\  + \ 4  x\^2 - \ 3\)], "Input"],

Cell[BoxData[
    \(Simplify[
      \((4  x\^3 + 5  x\^2 + 3)\)\  - \ 3 \((2  x\^2 - 6  x\  + \ 1)\)]\)], 
  "Input"],

Cell[BoxData[
    \(\((3  x\  + \ 2  y)\)\^8\)], "Input"],

Cell[TextData[{
  "That last one may not have been what you expected - or desired.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " simplifies automatically, but it won't expand, since that form won't \
usually be considered simplified.  We'll tell it to expand."
}], "Text"],

Cell[BoxData[
    \(Expand[\((3  x\  + \ 2  y)\)\^8]\)], "Input"],

Cell["\<\
Create a new cell below this one to \"Factor\" the last result.  \
(Remember that the command must be capitalized and square brackets are \
necessary.  Use \"%\" to refer to the last output, the expanded form.)\
\>", 
  "Text"],

Cell[TextData[{
  "Let's see a few more commands.  Consider the fraction  ",
  Cell[BoxData[
      \(TraditionalForm\`\(2  x\^2 - \ 3\)\/\(x\^2 - 3  x\  + \ 2\)\)]],
  ".  First, enter it by executing the cell, so that it is in the computer's \
memory."
}], "Text"],

Cell[BoxData[
    \(\(2  x\^2 - 3\)\/\(x\^2 - 3  x + 2\)\)], "Input"],

Cell[TextData[{
  "Now create new cells and ask ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to perform each of the following commands, one by one, on the previous \
result:  Apart, Together, Expand, ExpandAll, and Simplify.  (Use the \
capitalized command with the square brackets, and use \"%\" to refer to the \
last output.  Note that \"ExpandAll\" is written with a capital \"A\" but no \
space between the words.  It is one ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots", "Section",
  CellTags->"firstplot"],

Cell[TextData[{
  "\tThe graphics capabilities in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are spectacular. Here's the simplest of beginnings."
}], "Text"],

Cell[BoxData[
    \(Plot[x\^3 - \ 5  x\  + \ 2, \ {x, \ \(-4\), \ 4}]\)], "Input"],

Cell[BoxData[
    \(Plot[\((x^2\  - \ 3  x)\)\ Sin[x], \ {x, \ \(-3\), \ 4}]\)], "Input"],

Cell["\<\
The syntax should be clear. Edit the line above to change the \
domain and explore more of the graph.  Then create a couple more graphs.\
\>",
   "Text"]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowSize->{514, 426},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.100008, 0.6]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[0.820005, 0.949996, 0.949996]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00l0001804P000000_P2B?ofoo833P9F;085:0?l0@00005X0FP000003]P;J001
0@00I00100000@0200000BL?00400000000000000000030001000000000@0?o>
okX?AP^^0201000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "newcell"->{
    Cell[5303, 159, 727, 15, 108, "Text",
      CellTags->"newcell"]},
  "symbolic"->{
    Cell[6563, 193, 52, 1, 33, "Section",
      CellTags->"symbolic"]},
  "firstplot"->{
    Cell[8497, 258, 49, 1, 33, "Section",
      CellTags->"firstplot"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"newcell", 27812, 959},
  {"symbolic", 27899, 962},
  {"firstplot", 27988, 965}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 241, 10, 90, "Text"],
Cell[1953, 61, 118, 5, 41, "Title"],
Cell[2074, 68, 151, 4, 38, "Subtitle"],
Cell[2228, 74, 924, 17, 168, "Text"],

Cell[CellGroupData[{
Cell[3177, 95, 26, 0, 53, "Section"],
Cell[3206, 97, 465, 9, 77, "Text"],
Cell[3674, 108, 37, 1, 51, "Input"],
Cell[3714, 111, 385, 10, 60, "Text"],
Cell[4102, 123, 37, 1, 51, "Input"],
Cell[4142, 126, 534, 10, 91, "Text"],
Cell[4679, 138, 40, 1, 53, "Input"],
Cell[4722, 141, 534, 13, 76, "Text"],
Cell[5259, 156, 41, 1, 47, "Input"],
Cell[5303, 159, 727, 15, 108, "Text",
  CellTags->"newcell"],
Cell[6033, 176, 353, 6, 74, "Text"],
Cell[6389, 184, 71, 1, 62, "Input"],
Cell[6463, 187, 63, 1, 71, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6563, 193, 52, 1, 33, "Section",
  CellTags->"symbolic"],
Cell[6618, 196, 112, 3, 26, "Text"],
Cell[6733, 201, 82, 1, 49, "Input"],
Cell[6818, 204, 117, 3, 51, "Input"],
Cell[6938, 209, 57, 1, 49, "Input"],
Cell[6998, 212, 286, 6, 59, "Text"],
Cell[7287, 220, 65, 1, 51, "Input"],
Cell[7355, 223, 237, 5, 58, "Text"],
Cell[7595, 230, 265, 6, 48, "Text"],
Cell[7863, 238, 69, 1, 64, "Input"],
Cell[7935, 241, 525, 12, 93, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8497, 258, 49, 1, 33, "Section",
  CellTags->"firstplot"],
Cell[8549, 261, 173, 5, 43, "Text"],
Cell[8725, 268, 82, 1, 51, "Input"],
Cell[8810, 271, 89, 1, 47, "Input"],
Cell[8902, 274, 163, 4, 42, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

