(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10816,        332]*)
(*NotebookOutlinePosition[     29746,       1024]*)
(*  CellTagsIndexPosition[     29670,       1018]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Tutorial 2:  ",
  StyleBox["Intro to Palettes",
    FontSlant->"Italic"]
}], "Title",
  TextAlignment->Left,
  FontSize->30],

Cell["by R. Dover, IMSA", "Subtitle",
  TextAlignment->Left,
  FontSize->14],

Cell[TextData[{
  "\tThis tutorial will show you a bit of the versatility of using palettes.  \
And we'll review some of the ideas you saw in the first tutorial.  Before \
that, it is important to understand that commands may be entered in a variety \
of ways.  This flexibility is one of the major changes in the new version of \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", version 3.0.  Many experienced users work with a combination of \
palettes, keystrokes, and \"longhand,\" for lack of a better word.  (We'll \
consider using keystrokes later to do typesetting.)\n\tFirst, as a default, \
the \"Basic Input\" palette should appear to the right of this notebook.  The \
symbol ",
  Cell[BoxData[
      \(TraditionalForm\`\[Placeholder]\^\[Placeholder]\)]],
  "should appear in the upper left corner.  If not, under the \"File\" menu, \
choose \"Palettes\" and then \"Basic Input.\"  "
}], "Text"],

Cell[CellGroupData[{

Cell["Basic typesetting", "Section"],

Cell[TextData[{
  "\tWe'll create the expression  ",
  Cell[BoxData[
      \(TraditionalForm\`\(2\^5 + \ 12\/7\  + \ \@18.\ \ \ \)\)]],
  "Create a ",
  ButtonBox["new cell",
    ButtonData:>{"1 start.nb", "newcell"},
    ButtonStyle->"Hyperlink"],
  " below.  Move the cursor to the  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Placeholder]\^\[Placeholder]\)]],
  " in the palette and click. Type \"2\", and it should replace the lower, \
darkened box.  Press \[TabKey].  The exponent box should now appear darkened. \
Type \"5\" and press \[Rule], the right cursor key, to get out of the \
exponent.  Then type \"+\" and click on the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Placeholder]\/\[Placeholder]\)]],
  " symbol in the palette.  Enter 12 and press \[TabKey] to highlight the \
denominator box.  Enter 7 and use the right arrow key to move from the \
fraction.  Type another \"+\" and click on ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Placeholder]\)]],
  ".  Enter 18 and execute the cell.  "
}], "Text"],

Cell["Note that one could have also entered the following:", "Text"],

Cell[BoxData[
    \(2^5\  + \ 12/7\  + \ Sqrt[18]\)], "Input"],

Cell["\<\
\tTo obtain a numerical approximation of either form of the \
expression above, we've seen before that one can edit the line to place  \"N[ \
 ]\"  around the entire expression.  Do that on your expression.  \
Alternatively, one can type \"//N\" after an expression.  Do this on the \
second expression and execute the cell.  (This method is used quite \
frequently, and it may be used with other commands as well. One simply types \
\"//\" followed by the command.  It's handy as an after-thought.)\
\>", "Text",\

  CellTags->"numerical"],

Cell[TextData[{
  "Next, use the ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sum]\+\(\[Placeholder] = \[Placeholder]\)\%\[Placeholder] 
        \[Placeholder]\)]],
  "  button to find ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 1\)\%50 1\/k\)]],
  ".  As before, enter letters and numbers into the location with the black \
box.  Use the \[TabKey] key to move around the expression.  Use the right \
cursor key to move out of the summation expression.  "
}], "Text"],

Cell["Note that the same command may be entered as shown below.", "Text"],

Cell[BoxData[
    \(Sum[1/k, \ {k, \ 1, \ 50}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Special numbers", "Section"],

Cell[TextData[
"\tNumbers may also be entered in multiple ways.  Pi may be spelled out or \
the symbol \[Pi] may be taken from the palette.  Each of the following terms \
in the sum below is equivalent.  Any combination is fine."], "Text"],

Cell[BoxData[
    \(Sin[\[Pi]\/6] + Sin[Pi\/6] + Sin[Pi/6] + Sin[\[Pi]/6]\)], "Input"],

Cell["Execute the cell below to see the graph. ", "Text"],

Cell[BoxData[
    \(Plot[Exp[x], \ {x, \ \(-2\), \ 2}]\)], "Input"],

Cell[TextData[{
  "Instead of using the special function Exp, edit the command above to use ",
  
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^x\)]],
  " with the palette.  In addition, one may also use E^x, with the capital E \
to represent what is built-in."
}], "Text"],

Cell["Open the following subsection on complex numbers.", "Text"],

Cell[CellGroupData[{

Cell["Complex numbers", "Subsection"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)]],
  " may be obtained by choosing \[ImaginaryI]  from the palette or by typing \
",
  StyleBox["I",
    FontWeight->"Bold"],
  ", captitalized of course, since it is known by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  Enter each of the following."
}], "Text"],

Cell[BoxData[
    \(\((3\  + \ 4  \[ImaginaryI])\)\^5\)], "Input"],

Cell[BoxData[
    \(\(4 + 2  I\)\/\(5 - 3  I\)\)], "Input"],

Cell[BoxData[
    \(Conjugate[7 - 12  \[ImaginaryI]]\)], "Input"],

Cell["Try some others.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["More special numbers", "Subsection"],

Cell["\<\
Infinity is the next special \"number\" in the palette. (Sometimes, \
this doesn't show up well, especially on sums and integrals.  It may appear \
as a small black rectangle.)\
\>", "Text"],

Cell[BoxData[
    \(\[Sum]\+\(k = 1\)\%\[Infinity] 2\/3\^k\)], "Input"],

Cell["Equivalently, we have:", "Text"],

Cell[BoxData[
    \(Sum[2/3^k, \ {k, \ 1, \ Infinity}]\)], "Input"],

Cell["\<\
Create one of your own in each the of the two forms above.  Any \
combination of format is allowable.\
\>", "Text"],

Cell["\<\
The last symbol in this line may also come in handy at times.\
\>", 
  "Text"],

Cell[BoxData[
    \(Sin[30  \[Degree]] + \ Cos[30\ Degree]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["More palettes", "Section"],

Cell[CellGroupData[{

Cell["Algebra", "Subsection"],

Cell[TextData[{
  "\tUnder the \"File\" menu, choose \"Palettes\" and then \
\"AlgebraicManipulation.\"  Click on the very top of the palette and drag it \
to the right of the screen.  You will see several commands which we used in \
the ",
  ButtonBox["first notebook",
    ButtonData:>{"1 start.nb", "symbolic"},
    ButtonStyle->"Hyperlink"],
  " along with many others.  Again, using this palette gives us an \
alternative method of executing commands.  Consider the fraction below.  \
Highlight the entire fraction.  Then click on each of the following on the \
palette one at a time:  Expand, Apart, Simplify."
}], "Text"],

Cell[BoxData[
    \(\(5 + 3\ x\)\/\(\((\(-2\) + x)\)\^2\ \((1 + x)\)\)\)], "Input"],

Cell["\<\
Try a couple other commands if you wish.  Since the command \
ExpandAll is not in this palette, type \"//ExpandAll\"  after the fraction to \
see its effect.\
\>", "Text"],

Cell["As another example, Expand and then Factor the following.", "Text"],

Cell[BoxData[
    \(\((\[HappySmiley] + \[SadSmiley])\)\^6\)], "Input",
  FontSize->14],

Cell["Or would you prefer...", "Text"],

Cell[BoxData[
    \(\((3  \[LightBulb] + 2  \[Wolf])\)\^9\)], "Input"],

Cell[TextData[
"Use the same method of highlighting and then clicking on TrigExpand, \
TrigFactor, and TrigReduce to see what they do to the following.  (The \
\[Alpha] comes from the BasicInput palette.)"], "Text"],

Cell[BoxData[
    \(Sin[5  \[Alpha]]\)], "Input"],

Cell[TextData[
"Try some other coefficients of \[Alpha].  Then try Cos or Tan on some \
angles."], "Text"],

Cell["Use ExpToTrig on each of the following.", "Text"],

Cell[BoxData[
    \(\[ExponentialE]\^\(2  \[Pi]\ \[ImaginaryI]\)\)], "Input"],

Cell[BoxData[
    \(4\ E^\((2  Pi\ I/3)\)\)], "Input"],

Cell["Use TrigToExp on the next line.", "Text"],

Cell[BoxData[
    \(2\ \((Cos[\[Theta]] + I\ Sin[\[Theta]])\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["More commands", "Subsection"],

Cell[TextData[{
  "\tFirst, close the \"AlgebraicManipulation\" palette, just to unclutter \
the desktop.  Under \"File,\" choose \"Palettes\" and \"BasicCalculations.\"  \
Drag the palette to the side if necessary.  As you can see, there's quite a \
bit to choose from here.  Look around a little it by clicking on the \
triangles to the left to open or close a subsection.  By now, several of \
these buttons and commands will look familiar.  (Others will show some of \
what's yet to come!)   For example, under \"Algebra,\" check \"Complex \
Numbers.\"  We've used \"Conjugate\" before for complex numbers, but there \
are other similar commands.  \n\tOpen the section on \"Graphics.\"  You'll \
notice a short explanation of the format.  Click on ",
  StyleBox[
  " Plot[\[SelectionPlaceholder], {\[Placeholder],\[Placeholder],\
\[Placeholder]}]",
    FontWeight->"Bold"],
  ".  Enter a function to be graphed in the black box.  Then \[TabKey] to \
subsequent boxes, filling them in as you go, with the variable x, xmin, and \
xmax.  (Don't worry.  We'll come back to a number of the other graphs a \
little later.)"
}], "Text"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
CellGrouping->Manual,
WindowSize->{484, 400},
WindowMargins->{{10, Automatic}, {Automatic, 7}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.100008, 0.6]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[0.820005, 0.949996, 0.949996]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00l0001804P000000_P2B?ofoo833P9F;085:0?l0@00005X0FP000003]P;J001
0@00I00100000@0200000BL?00400000000000000000030001000000000@0?o>
okX?AP^^0201000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "numerical"->{
    Cell[4082, 114, 550, 10, 106, "Text",
      CellTags->"numerical"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"numerical", 29572, 1011}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 143, 6, 46, "Title"],
Cell[1855, 57, 76, 2, 34, "Subtitle"],
Cell[1934, 61, 918, 17, 167, "Text"],

Cell[CellGroupData[{
Cell[2877, 82, 36, 0, 53, "Section"],
Cell[2916, 84, 1027, 23, 134, "Text"],
Cell[3946, 109, 68, 0, 26, "Text"],
Cell[4017, 111, 62, 1, 47, "Input"],
Cell[4082, 114, 550, 10, 106, "Text",
  CellTags->"numerical"],
Cell[4635, 126, 489, 12, 61, "Text"],
Cell[5127, 140, 73, 0, 26, "Text"],
Cell[5203, 142, 59, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5299, 148, 34, 0, 33, "Section"],
Cell[5336, 150, 239, 3, 58, "Text"],
Cell[5578, 155, 86, 1, 62, "Input"],
Cell[5667, 158, 57, 0, 26, "Text"],
Cell[5727, 160, 67, 1, 47, "Input"],
Cell[5797, 163, 285, 7, 42, "Text"],
Cell[6085, 172, 65, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[6175, 176, 37, 0, 43, "Subsection"],
Cell[6215, 178, 354, 12, 46, "Text"],
Cell[6572, 192, 66, 1, 49, "Input"],
Cell[6641, 195, 59, 1, 62, "Input"],
Cell[6703, 198, 65, 1, 47, "Input"],
Cell[6771, 201, 32, 0, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6840, 206, 42, 0, 27, "Subsection"],
Cell[6885, 208, 200, 4, 42, "Text"],
Cell[7088, 214, 71, 1, 69, "Input"],
Cell[7162, 217, 38, 0, 26, "Text"],
Cell[7203, 219, 67, 1, 47, "Input"],
Cell[7273, 222, 125, 3, 42, "Text"],
Cell[7401, 227, 88, 3, 26, "Text"],
Cell[7492, 232, 71, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7612, 239, 32, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[7669, 243, 29, 0, 43, "Subsection"],
Cell[7701, 245, 628, 12, 106, "Text"],
Cell[8332, 259, 83, 1, 64, "Input"],
Cell[8418, 262, 181, 4, 42, "Text"],
Cell[8602, 268, 73, 0, 26, "Text"],
Cell[8678, 270, 87, 2, 51, "Input"],
Cell[8768, 274, 38, 0, 26, "Text"],
Cell[8809, 276, 70, 1, 49, "Input"],
Cell[8882, 279, 215, 3, 58, "Text"],
Cell[9100, 284, 49, 1, 47, "Input"],
Cell[9152, 287, 106, 2, 26, "Text"],
Cell[9261, 291, 55, 0, 26, "Text"],
Cell[9319, 293, 77, 1, 50, "Input"],
Cell[9399, 296, 54, 1, 47, "Input"],
Cell[9456, 299, 47, 0, 26, "Text"],
Cell[9506, 301, 74, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9617, 307, 35, 0, 27, "Subsection"],
Cell[9655, 309, 1133, 19, 199, "Text"]
}, Closed]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

