(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9403,        311]*)
(*NotebookOutlinePosition[     28405,       1006]*)
(*  CellTagsIndexPosition[     28307,        999]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Tutorial 4: ",
  StyleBox[" Lists and Tables",
    FontSlant->"Italic"]
}], "Title",
  TextAlignment->Left,
  FontSize->30],

Cell["by R. Dover, IMSA", "Subtitle",
  TextAlignment->Left,
  FontSize->14],

Cell[CellGroupData[{

Cell["Lists and tables", "Section"],

Cell[TextData[{
  "\tCurly braces are used quite often in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  They are used primarily for lists of objects, but they may also be used \
for indices and for domains of functions.\n\tFirst, we'll create a short list \
and perform several operations on it.  Execute each cell below."
}], "Text"],

Cell[BoxData[
    \({2, \ 3, \ 5, \ 8, \ 13}\)], "Input"],

Cell[BoxData[
    \(%\^2 - \ 1\)], "Input"],

Cell[BoxData[
    \(%%  x\  + \ 1\)], "Input"],

Cell["\<\
As you recall, the \"%\" refers to the last output. \"%%\" refers \
to the second to the last output.  Had we planned on doing much with our \
list, it would have been simpler to give it a name.
\tClearly, the need may come to generate a list - here, called a \"table.\"  \
We'll name this one.\
\>", "Text",
  CellTags->"prevout"],

Cell[BoxData[
    \(ourlist\  = \ Table[2  i, \ {i, \ 1, \ 10}]\)], "Input",
  CellTags->"table"],

Cell["\<\
Note that output is in fact a list with curly braces.  Square each \
of the values in ourlist.  Then divide each term by 6 and find numerical \
approximations.\
\>", "Text"],

Cell[TextData[
"Execute the following.  Note that the symbol \[SelectionPlaceholder]\
\[LeftDoubleBracket]\[Placeholder]\[RightDoubleBracket] may be found on the \
palette."], "Text"],

Cell[BoxData[
    \(ourlist\[LeftDoubleBracket]4\[RightDoubleBracket]\)], "Input"],

Cell["\<\
Edit the line above to change the number 4.  Be sure you understand \
what this notation does.\
\>", "Text"],

Cell["Now we'll check out a little trig.", "Text"],

Cell[BoxData[
    \(Table[Cos[n\ \[Pi]], \ {n, \ 0, \ 1, \ 1/6}]\)], "Input"],

Cell["\<\
Note the effect of the 1/6 above, the optional extra term inside \
the curly braces for the index.\
\>", "Text"],

Cell["\<\
We may also create a list of lists by creating a table of a list.\
\
\>", "Text"],

Cell[BoxData[
    \(Table[{i, \ i\^2, \ i\^3}, \ {i, \ 1, \ 20}]\)], "Input"],

Cell["\<\
This is rather difficult to view.  Use the command \"TableForm\" on \
the last output.  (Either type \"//TableForm\" at the end of the line above \
or type \"TableForm[   ]\" around the command so that it begins \
\"TableForm[Table[...\"  Watch the capital letters on both words.  There is \
no space between the words since it is one command.)\
\>", "Text"],

Cell[TextData[{
  ButtonBox["Define",
    ButtonData:>{"3 define.nb", "definef"},
    ButtonStyle->"Hyperlink"],
  " a function f.  Then create a table and display is using \"TableForm\" \
which will show the ordered pairs (x, f(x)) for 0 \[LessEqual] x \[LessEqual] \
5 by steps of 0.2."
}], "Text"],

Cell[TextData[{
  "When you are done, be sure to ",
  ButtonBox["clear",
    ButtonData:>{"3 define.nb", "clear"},
    ButtonStyle->"Hyperlink"],
  " f and ourlist."
}], "Text"],

Cell[CellGroupData[{

Cell["More numerics", "Subsection"],

Cell[TextData[{
  "Did you notice that the terms in the last table you created came out in \
decimal form?  Curious.  Previously, we had to tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to give answers in ",
  ButtonBox["decimal form",
    ButtonData:>{"2 palettes.nb", "numerical"},
    ButtonStyle->"Hyperlink"],
  ".  Here, note what you entered for the step size.  Edit that command, \
replacing 0.2 by 1/5.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " assumes that if you put decimals in, you want decimals out.  In other \
words, it's another method to ask for a decimal output.  Try this on a couple \
other commands."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Vectors", "Section"],

Cell["\<\
\tLet's create and name two vectors, v and w.  (The letters are not \
capitalized to distinguish them from any built-in names.)  Vectors are simply \
lists.\
\>", "Text"],

Cell[BoxData[
    \(v\  = \ {2, \ \(-5\), \ 1}; \ w\  = \ {1, \ 2, \ \(-3\)}\)], "Input"],

Cell["Find the scalar product 4v.  Then find 2v - 3w.", "Text"],

Cell["Execute the next cell. What does the program assume about c?", "Text"],

Cell[BoxData[
    \(c + \ v\)], "Input"],

Cell[TextData[{
  "The dot product is denoted by v.w, where that's a period between the two \
vectors.  Try it.  Then ask ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " if this operation on these vectors is commutative."
}], "Text"],

Cell["Try the cross product.", "Text"],

Cell[BoxData[
    \(Cross[v, \ w]\)], "Input"],

Cell[TextData[
"Alternatively, use the following notation with the cute little \
\"\[Cross]\"."], "Text"],

Cell[BoxData[
    \(v\ \[Cross]w\)], "Input"],

Cell["When finished, clear v and w.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Matrices", "Section"],

Cell[TextData[{
  "\tMatrices may be expressed in two ways.  Either way, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " see a matrix as a list of lists.  We define mat1 by using the palette."
}], "Text"],

Cell[BoxData[
    RowBox[{"mat1", " ", "=", " ", 
      RowBox[{"(", GridBox[{
            {"3", "5"},
            {\(-1\), "2"}
            }], ")"}]}]], "Input"],

Cell[TextData[{
  "Curious output.  This looks like the list of lists mentioned earlier with \
braces within braces. Select the output cell by clicking on the bracket at \
the right.  Under the \"Cell\" menu, select \"Convert to\" and choose \
\"TraditionalForm.\"  This will look nicer, but ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is sometimes a little less confident of this notation.  Note the new \
markings in the cell bracket.  Alternatively, create mat2 as follows and, on \
another line, use the command \"MatrixForm[mat2]\"."
}], "Text"],

Cell[BoxData[
    \(mat2\  = {{2, \ 0}, \ {3, \ 1}}\)], "Input"],

Cell["\<\
Several commands work as expected on matrices.  Find 3mat1, the \
determinant by using 
Det[mat1], and MatrixPower[mat1, 3] to represent the 3rd power of the matrix. \
 Express these in MatrixForm. (Alternatively, one may type \"//MatrixForm\" \
after any expression.)\
\>", "Text"],

Cell["Then find the \"Transpose\" and the \"Inverse\" of mat2.  ", "Text"],

Cell[TextData[{
  "Now find mat1 + mat2  and  mat1.mat2, using the period to represent \
multiplication as we did before. What happens if one executes the command ",
  Cell[BoxData[
      \(TraditionalForm\`mat1\^2\)]],
  "?"
}], "Text"],

Cell["So check this out.  What should the result be?", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", GridBox[{
            {"a", "b"},
            {"c", "d"}
            }], ")"}], ".", 
      RowBox[{"Inverse", "[", 
        RowBox[{"(", GridBox[{
              {"a", "b"},
              {"c", "d"}
              }], ")"}], "]"}]}]], "Input"],

Cell["\<\
\"Fix\" that by using Simplify on the command above.  Look better?
\tWant a different size or shape?  Obviously, this may be created using the \
curly braces, but it may also be entered in matrix form.  From the \"Input\" \
menu, choose \"Create Table/Matrix/Palette...\"  Under \"Make,\" choose \
\"Matrix\" and choose the size and shape you wish.  Fill in values as \
desired.  Name this mat3.  \
\>", "Text"],

Cell["\<\
Now determine what each of the following commands does.  (Hopefully \
your matrix isn't too small!)\
\>", "Text"],

Cell[BoxData[
    \(mat3\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(mat3\[LeftDoubleBracket]3, \ 2\[RightDoubleBracket]\)], "Input"]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowSize->{503, 403},
WindowMargins->{{20, Automatic}, {Automatic, 8}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.100008, 0.6]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[0.820005, 0.949996, 0.949996]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00l0001804P000000_P2B?ofoo833P9F;085:0?l0@00005X0FP000003]P;J001
0@00I00100000@0200000BL?00400000000000000000030001000000000@0?o>
okX?AP^^0201000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "prevout"->{
    Cell[2500, 83, 341, 7, 86, "Text",
      CellTags->"prevout"]},
  "table"->{
    Cell[2844, 92, 97, 2, 47, "Input",
      CellTags->"table"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"prevout", 28135, 989},
  {"table", 28216, 992}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 142, 6, 46, "Title"],
Cell[1854, 57, 76, 2, 34, "Subtitle"],

Cell[CellGroupData[{
Cell[1955, 63, 35, 0, 53, "Section"],
Cell[1993, 65, 349, 7, 87, "Text"],
Cell[2345, 74, 57, 1, 47, "Input"],
Cell[2405, 77, 43, 1, 49, "Input"],
Cell[2451, 80, 46, 1, 47, "Input"],
Cell[2500, 83, 341, 7, 86, "Text",
  CellTags->"prevout"],
Cell[2844, 92, 97, 2, 47, "Input",
  CellTags->"table"],
Cell[2944, 96, 183, 4, 42, "Text"],
Cell[3130, 102, 183, 3, 26, "Text"],
Cell[3316, 107, 82, 1, 47, "Input"],
Cell[3401, 110, 118, 3, 26, "Text"],
Cell[3522, 115, 50, 0, 26, "Text"],
Cell[3575, 117, 77, 1, 47, "Input"],
Cell[3655, 120, 122, 3, 26, "Text"],
Cell[3780, 125, 91, 3, 26, "Text"],
Cell[3874, 130, 77, 1, 51, "Input"],
Cell[3954, 133, 368, 6, 74, "Text"],
Cell[4325, 141, 300, 7, 42, "Text"],
Cell[4628, 150, 177, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[4830, 160, 35, 0, 43, "Subsection"],
Cell[4868, 162, 670, 16, 96, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5587, 184, 26, 0, 33, "Section"],
Cell[5616, 186, 180, 4, 42, "Text"],
Cell[5799, 192, 89, 1, 47, "Input"],
Cell[5891, 195, 63, 0, 26, "Text"],
Cell[5957, 197, 76, 0, 26, "Text"],
Cell[6036, 199, 40, 1, 47, "Input"],
Cell[6079, 202, 244, 6, 43, "Text"],
Cell[6326, 210, 38, 0, 26, "Text"],
Cell[6367, 212, 46, 1, 47, "Input"],
Cell[6416, 215, 105, 2, 26, "Text"],
Cell[6524, 219, 45, 1, 47, "Input"],
Cell[6572, 222, 45, 0, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6654, 227, 27, 0, 33, "Section"],
Cell[6684, 229, 215, 5, 43, "Text"],
Cell[6902, 236, 163, 5, 60, "Input"],
Cell[7068, 243, 565, 10, 107, "Text"],
Cell[7636, 255, 64, 1, 47, "Input"],
Cell[7703, 258, 292, 6, 70, "Text"],
Cell[7998, 266, 74, 0, 26, "Text"],
Cell[8075, 268, 237, 6, 43, "Text"],
Cell[8315, 276, 62, 0, 26, "Text"],
Cell[8380, 278, 288, 10, 60, "Input"],
Cell[8671, 290, 421, 7, 102, "Text"],
Cell[9095, 299, 123, 3, 42, "Text"],
Cell[9221, 304, 79, 1, 47, "Input"],
Cell[9303, 307, 84, 1, 47, "Input"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

