(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7990,        266]*)
(*NotebookOutlinePosition[     27000,        961]*)
(*  CellTagsIndexPosition[     26901,        954]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Tutorial 5:  ",
  StyleBox["Plotting",
    FontSlant->"Italic"]
}], "Title",
  TextAlignment->Left,
  FontSize->30],

Cell["by R. Dover, IMSA", "Subtitle",
  TextAlignment->Left,
  FontSize->14],

Cell[CellGroupData[{

Cell["Basic graphs", "Section"],

Cell[TextData[{
  "\tOne of the many strengths of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is its graphing capabilities.  You created a couple of ",
  ButtonBox["simple 2-D plots",
    ButtonData:>{"1 start.nb", "firstplot"},
    ButtonStyle->"Hyperlink"],
  " in the first tutorial, but let's review that here.  And there's much more \
to see.\n\tThe coding below is for the graph of f(x) = x sin(2x) for -1 \
\[LessEqual] x \[LessEqual] 5.  (Again, note the space between ",
  StyleBox["x",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Sin[2x]",
    FontWeight->"Bold"],
  " to denote multiplication.  Otherwise, this would be seen as one variable \
\"xSin\".)"
}], "Text"],

Cell[BoxData[
    \(Plot[x\ Sin[2  x], \ {x, \ \(-1\), \ 5}]\)], "Input"],

Cell["\<\
As a default, the range is chosen automatically.  This and other \
options may be controlled by the user.  As examples, check the following to \
see the results of each command.  Look at each one carefully.  There are lots \
of arrows, braces, capitals, and commas to watch.  Understanding the system \
will make it much easier to use a variety of options.\
\>", "Text"],

Cell[BoxData[
    \(Plot[x\ Sin[2  x], \ {x, \ \(-1\), \ 5}, \ Frame\  \[Rule] \ True]\)], 
  "Input"],

Cell[BoxData[
    \(Plot[x\ Sin[2  x], \ {x, \ \(-1\), \ 5}, \ 
      PlotRange\  \[Rule] \ {\(-5\), \ 5}]\)], "Input"],

Cell[BoxData[
    \(Plot[x\ Sin[2  x], \ {x, \ \(-1\), \ 5}, \ 
      PlotStyle\  \[Rule] \ {{Dashing[{.03}], \ Thickness[.01]}}]\)], "Input"],

Cell[BoxData[
    \(Plot[x\ Sin[2  x], \ {x, \ \(-1\), \ 5}, \ 
      AspectRatio\  \[Rule] \ Automatic, \ 
      Ticks\  \[Rule] {{\[Pi]/2, \ \[Pi], \ 3  \[Pi]/2}, \ Automatic}]\)], 
  "Input"],

Cell[BoxData[
    \(Plot[x\ Sin[2  x], \ {x, \ \(-1\), \ 5}, \ 
      PlotLabel\  \[Rule] \ "\<f[x] = x Sin[2x]\>"]\)], "Input"],

Cell["\<\
Create one of your own graphs.  Then make several changes including \
the range, the styles, and the tickmarks.  Vary the values used by dashing \
and thickness to see the effects.  Experiment for a while.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Help!", "Section"],

Cell[TextData[{
  "\tClearly, there are lots of commands and options in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". And clearly, it's impossible to remember all of them. Fortunately, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " also provides a lot of help.  First suppose you have forgotten the basic \
coding for Plot.  We saw earlier that this command is available through the \
BasicCalculations palette.  To see an explanation, execute the cell below. "
}], "Text"],

Cell[BoxData[
    \(\(?Plot\)\)], "Input"],

Cell[TextData[{
  "As you can see, this can be quite helpful.  This technique works for all \
of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in functions.  Try it for a few of the other commands we have \
used."
}], "Text"],

Cell["\<\
But what about options?  What options may be used with the command? \
 Ask it.\
\>", "Text"],

Cell[BoxData[
    \(Options[Plot]\)], "Input",
  CellTags->"options"],

Cell["\<\
Whoa!  Read through the list carefully.  You will note the the \
default value for each option is shown.  \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Colors", "Section",
  CellTags->"colors"],

Cell["\<\
\tThere are two basic methods of showing colors.  The first uses \
Red, Green, and Blue.  (\"Log\" refers to the natural logarithm.)\
\>", "Text"],

Cell[BoxData[
    \(Plot[x\ Log[x + 2], \ {x, \ \(-1.99\), \ 3}, \ 
      PlotStyle\  \[Rule] \ RGBColor[1, \ 0, \ 0]]\)], "Input"],

Cell["\<\
Make the graph blue instead of red.  Then try combining the three \
colors by using numbers between 0 and 1, inclusive, in the 3 locations.\
\>", 
  "Text"],

Cell[TextData[{
  "\tA second way to show a graph in color is by using ",
  StyleBox["Hue[k]",
    FontWeight->"Bold"],
  ".  One example is shown.  Try other values for k between 0 and 1, \
remembering your rainbow. "
}], "Text"],

Cell[BoxData[
    \(Plot[x\ Log[x + 2], \ {x, \ \(-1.99\), \ 3}, \ 
      PlotStyle\  \[Rule] \ Hue[.4]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["More graphs", "Section"],

Cell["\<\
\tTo graph two or more functions on one graph, we create a list of \
functions.\
\>", "Text"],

Cell[BoxData[
    \(Plot[{x\ Sin[2  x], \ x\^3\  - \ 3  x\  + \ 1}, \ {x, \ \(-4\), \ 4}]
      \)], "Input"],

Cell["\<\
Though this will be fine in some cases, options may be particularly \
helpful to clarify which graph is which .  To correspond to the list of \
functions, we create a list of styles.  Pay close attention here. \
\>", 
  "Text"],

Cell[BoxData[
    \(Plot[{x\ Sin[2  x], \ x\^3\  - \ 3  x\  + \ 1}, \ {x, \ \(-4\), \ 4}, \ 
      PlotStyle\  \[Rule] \ \ {Thickness[.03], \ Dashing[{.02}]}]\)], "Input"],

Cell["\<\
Note the curly braces.  Check back to see how we added two styles \
to one graph in the first section of this tutorial.  This is different, since \
we have given one style to each of two graphs.\
\>", "Text"],

Cell["Perhaps you prefer the more colorful look:", "Text"],

Cell[BoxData[
    \(Plot[{x\ Sin[2  x], \ x\^3\  - \ 3  x\  + \ 1}, \ {x, \ \(-4\), \ 4}, \ 
      PlotStyle\  \[Rule] \ {Hue[0], \ Hue[.6]}]\)], "Input"],

Cell["Or both looks:", "Text"],

Cell[BoxData[
    \(Plot[{x\ Sin[2  x], \ x\^3\  - \ 3  x\  + \ 1}, \ {x, \ \(-4\), \ 4}, \ 
      PlotStyle\  \[Rule] 
        \ {{Hue[0], \ Thickness[.03]}, \ {\ Hue[.6], \ Dashing[{.02}]}}]\)], 
  "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Your turn...", "Section"],

Cell[TextData[{
  "Let f(x) = cosx and g(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`1 - x\^2\)]],
  ".  Define both of these functions.  "
}], "Text"],

Cell["\<\
Plot them together, making f  blue and thick while g is green with \
dashes.  Put a frame around the plot and label it \"Approximations.\" \
\>", 
  "Text"],

Cell["Be sure to clear f and g when you are done.", "Text"]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowSize->{506, 366},
WindowMargins->{{31, Automatic}, {37, Automatic}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.100008, 0.6]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[0.820005, 0.949996, 0.949996]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00l0001804P000000_P2B?ofoo833P9F;085:0?l0@00005X0FP000003]P;J001
0@00I00100000@0200000BL?00400000000000000000030001000000000@0?o>
okX?AP^^0201000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "options"->{
    Cell[5033, 158, 69, 2, 47, "Input",
      CellTags->"options"]},
  "colors"->{
    Cell[5272, 170, 47, 1, 33, "Section",
      CellTags->"colors"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"options", 26723, 944},
  {"colors", 26806, 947}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 134, 6, 46, "Title"],
Cell[1846, 57, 76, 2, 34, "Subtitle"],

Cell[CellGroupData[{
Cell[1947, 63, 31, 0, 53, "Section"],
Cell[1981, 65, 696, 18, 120, "Text"],
Cell[2680, 85, 73, 1, 47, "Input"],
Cell[2756, 88, 380, 6, 74, "Text"],
Cell[3139, 96, 102, 2, 47, "Input"],
Cell[3244, 100, 119, 2, 47, "Input"],
Cell[3366, 104, 142, 2, 63, "Input"],
Cell[3511, 108, 194, 4, 79, "Input"],
Cell[3708, 114, 128, 2, 63, "Input"],
Cell[3839, 118, 229, 4, 58, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4105, 127, 24, 0, 33, "Section"],
Cell[4132, 129, 499, 10, 92, "Text"],
Cell[4634, 141, 42, 1, 47, "Input"],
Cell[4679, 144, 246, 7, 43, "Text"],
Cell[4928, 153, 102, 3, 26, "Text"],
Cell[5033, 158, 69, 2, 47, "Input",
  CellTags->"options"],
Cell[5105, 162, 130, 3, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5272, 170, 47, 1, 33, "Section",
  CellTags->"colors"],
Cell[5322, 173, 156, 3, 42, "Text"],
Cell[5481, 178, 131, 2, 63, "Input"],
Cell[5615, 182, 166, 4, 42, "Text"],
Cell[5784, 188, 230, 6, 43, "Text"],
Cell[6017, 196, 117, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6171, 203, 30, 0, 33, "Section"],
Cell[6204, 205, 103, 3, 26, "Text"],
Cell[6310, 210, 109, 2, 51, "Input"],
Cell[6422, 214, 237, 5, 58, "Text"],
Cell[6662, 221, 171, 2, 70, "Input"],
Cell[6836, 225, 218, 4, 42, "Text"],
Cell[7057, 231, 58, 0, 26, "Text"],
Cell[7118, 233, 154, 2, 70, "Input"],
Cell[7275, 237, 30, 0, 26, "Text"],
Cell[7308, 239, 208, 4, 87, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7553, 248, 31, 0, 33, "Section"],
Cell[7587, 250, 156, 5, 27, "Text"],
Cell[7746, 257, 166, 4, 42, "Text"],
Cell[7915, 263, 59, 0, 26, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

