(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10648,        355]*)
(*NotebookOutlinePosition[     29433,       1040]*)
(*  CellTagsIndexPosition[     29389,       1036]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Tutorial 8:  ",
  StyleBox["Solving Equations",
    FontSlant->"Italic"]
}], "Title",
  TextAlignment->Left,
  FontSize->30],

Cell["by R. Dover, IMSA", "Subtitle",
  TextAlignment->Left,
  FontSize->14],

Cell[CellGroupData[{

Cell["Basics", "Section"],

Cell["\<\
\t\"Solve\" is a good place to start.  Check out the following.  \
Note the double \"=\" sign.\
\>", "Text"],

Cell[BoxData[
    \(Solve[x\^2 - \ x\  - \ 6\  == \ 0]\)], "Input"],

Cell[BoxData[
    \(Solve[x\^2 - \ x\  + \ 6\  == \ 0]\)], "Input"],

Cell[BoxData[
    \(Solve[2  Sin[x]^2\  - \ Sin[x]\  - \ 1 == 0]\)], "Input"],

Cell[TextData[{
  "That last one was interesting.  Often, to avoid such problems and \
potential problems, we let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " know what we are trying to solve for.  Try it again, with a new ending."
}], "Text"],

Cell[BoxData[
    \(Solve[2  Sin[x]^2\  - \ Sin[x]\  - \ 1 == 0, \ x]\)], "Input"],

Cell["\<\
This still has some problems.  We'll come back to that later.  \
Indicating the variable at the end is generally a good habit, and it can also \
allow us to deal with several variables.\
\>", "Text"],

Cell[BoxData[
    \(Solve[x\^2\  + \ x\ y\  + \ 2  y\^2\  == \ 4, \ x]\)], "Input"],

Cell["Edit the line above to solve for y instead of x.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Some work...and some don't", "Section"],

Cell[BoxData[
    \(Solve[x\^3 - \ 6  x\  + \ 2\  == \ 0, \ x]\)], "Input"],

Cell[TextData[{
  "In a new cell, under the \"Input\" menu, choose \"Copy Input from Above.\" \
 Edit the line to change the ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  "to ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^4.\)\)]],
  " It's interesting.  Edit the problem once again to use ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5.\)]],
  "  Unfortunately, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can't do everything.  On the other hand, solve ",
  Cell[BoxData[
      \(TraditionalForm\`x\^6 = \ 64.\)]]
}], "Text"],

Cell["\<\
Generally, \"Solve\" can handle polynomial equations through the \
4th degree - and a few other things here and there.  For algebraic equations, \
\"NSolve\" will help a great deal.\
\>", "Text"],

Cell[BoxData[
    \(NSolve[x\^5 - \ 6  x\  + \ 2\  == \ 0, \ x]\)], "Input"],

Cell[BoxData[
    \(NSolve[x\^4 - \ \@\(2  x\) + \ 3  x\  == \ 6, \ x]\)], "Input"],

Cell["Try some others.", "Text"],

Cell["But this won't take care of everything.", "Text"],

Cell[BoxData[
    \(NSolve[x\  - \ Cos[x]\  == \ 0, \ x]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Checking results", "Section"],

Cell["\tFirst we'll define a function f.", "Text"],

Cell[BoxData[
    \(f[x_] := x^4\  + 12  x^3\  - \ 305  x^2\  - \ 1056  x\  + \ 3220\)], 
  "Input"],

Cell["Let's call our solution set \"solns.\"", "Text"],

Cell[BoxData[
    \(solns\  = \ Solve[f[x]\  == \ 0, \ x]\)], "Input"],

Cell["\<\
Use TableForm to display the output.  Here, this really isn't \
necessary because the numbers are quite nice.  Sometimes, however, the \
answers are much easier to read in this format.\
\>", "Text"],

Cell["Check these values by replacing them into the function.", "Text"],

Cell[BoxData[
    \(f[x]\  /. \ solns\)], "Input"],

Cell[TextData[{
  "This shows one of the reasons that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " shows the solution set in this format - to make substitution (into any \
equation) quite easy.  Then clear both f and solns."
}], "Text"],

Cell[BoxData[
    \(Clear[f, \ solns]\)], "Input"],

Cell[TextData[{
  "Repeat the same steps above using \"NSolve\" with the function f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^4 - 6  x\^3 + \ 3  x\  + \ 8.\)]],
  " When you are done, clear your function and the name of your solution set. \
 (Alternatively, one can simply refer to the ",
  ButtonBox["previous output",
    ButtonData:>{"4 tables.nb", "prevout"},
    ButtonStyle->"Hyperlink"],
  " rather than naming the solution set.)\n"
}], "Text"],

Cell[CellGroupData[{

Cell["Out of order?", "Subsection"],

Cell[TextData[{
  "\tDid you make a mistake somewhere so that \"%\" or even \"%%\"  just \
won't work? See if this scenario sounds familiar:  You made a spelling error \
in an input line with a \"%\".  You correct the spelling only to try to \
execute the corrected command on the faulty output.  When this occurs, \
replace the \"%\" with",
  StyleBox[" Out[ ]",
    FontWeight->"Bold"],
  ",   putting the number of the proper output line in the square brackets."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Another method", "Section"],

Cell["\<\
\tThe command \"FindRoot\" uses an iterative process called \
Newton's Method, and it requires an initial input which is fairly close to \
the actual root being sought.  Let's deal with the equation  x - Cos[x] == 0.\
\
\>", "Text"],

Cell[BoxData[
    \(FindRoot[x\  - \ Cos[x]\  == \ 0, \ {x, \ 1}]\)], "Input"],

Cell[TextData[{
  "As another example, consider the cubic f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3 + 5  x\^2 - 7.\)]],
  " First, we'll define the function, calling it f.  (How clever!)"
}], "Text"],

Cell[BoxData[
    \(f[x_] := x\^3 + 5  x\^2 - 7\)], "Input"],

Cell["\<\
Plot the function.  Choose an appropriate domain so that you can \
see the three roots.\
\>", "Text"],

Cell["\<\
Since the smallest root is near x = -5, we'll use FindRoot and \
Newton's Method with this as an initial guess.\
\>", "Text"],

Cell[BoxData[
    \(FindRoot[f[x]\  == \ 0, \ {x, \ \(-5\)}]\)], "Input"],

Cell["\<\
Based on your plot above, choose nice x-values as initial estimates \
to find the other two roots.  Note that bad choices for initial inputs (too \
far away, past a max or min, for example) can lead to some unexpected \
results.\
\>", "Text"],

Cell[BoxData[
    \(Clear[f]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Systems", "Section"],

Cell[TextData[{
  "\tHere, we will solve a system of two equations, y = 2x - 3 and ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 - 5  x + 2  xy + y\^2 = 6.\)]],
  " First, we will graph the system to check for approximate solutions.  We \
will use a new method to do this. Before this can be done, use \"Help\" and \
load the package \"ImplicitPlot.\"  Execute the cells to name and plot each \
of the graphs separately."
}], "Text"],

Cell[BoxData[
    \(gr1 = 
      ImplicitPlot[x\^2 - \ 5  x\  + \ 2  x\ y\  + \ y\^2 == \ 6, 
        \ {x, \ \(-4\), \ 5}]\)], "Input"],

Cell[BoxData[
    \(gr2\  = \ Plot[2  x\  - \ 3, \ {x, \ \(-3\), \ 4}]\)], "Input"],

Cell["\<\
The interesting part is to combine the two graphs.  Use the command \
\"Show.\"  Note that the graph shown is on the intersection of the two \
domains given.\
\>", "Text"],

Cell[BoxData[
    \(Show[gr1, \ gr2]\)], "Input"],

Cell["\<\
To solve, we need a list of equations and a list of variables for \
which we wish to solve.\
\>", "Text"],

Cell[BoxData[
    \(NSolve[{x\^2 - 5  x\  + \ 2  x\ y\  + \ y\^2 == 6, \ 
        y\  == \ 2  x\  - 3}, \ {x, \ y}]\)], "Input"],

Cell["Create some other systems, implicit or not, and solve them.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["One more example", "Section"],

Cell[TextData[{
  "\tIn the last section, you looked at the graph and solved the system.  \
Here, we'll go a little further in putting several pieces together.\n\tLet's \
consider two polynomials: f(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^4 - 6  x\^2 + 2  x + 5\)]],
  " and g(x) = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3 - 3  x + 1.\)]],
  "  First, ",
  ButtonBox["define",
    ButtonData:>{"3 define.nb", "definef"},
    ButtonStyle->"Hyperlink"],
  " both functions."
}], "Text"],

Cell[TextData[{
  "Plot both functions together, finding an appropriate domain. Add options \
to show both graphs in different ",
  ButtonBox["colors",
    ButtonData:>{"5 plot.nb", "colors"},
    ButtonStyle->"Hyperlink"],
  " to make it easier to distinguish them."
}], "Text"],

Cell[TextData[
"Now try to estimate the points of intersection.  To do this, click anywhere \
on the graph to select it.  A box should appear around the graph.  Hold the \
command key (\[CloverLeaf]) down (Macintosh) or Alt key (Windows) and move \
the cursor around the graph.  The coordinates of the cursor should appear in \
the lower left corner.  (This does not trace, but it will give decent \
approximations.) Now try to solve the equation with \"Solve.\""], "Text"],

Cell["\<\
Whoa!  You may wish to scroll back through this and check it out.  \
That was a list of four solutions.  Let's work on approximations instead.  \
Edit the command to use \"NSolve.\" \
\>", "Text"],

Cell["\<\
Substitute this list of values into either f or g to find the \
corresponding y-values.  Do the ordered pairs seem to agree with your \
graphical approximations?\
\>", "Text"]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowSize->{520, 365},
WindowMargins->{{23, Automatic}, {30, Automatic}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.100008, 0.6]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[0.820005, 0.949996, 0.949996]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00l0001804P000000_P2B?ofoo833P9F;085:0?l0@00005X0FP000003]P;J001
0@00I00100000@0200000BL?00400000000000000000030001000000000@0?o>
okX?AP^^0201000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 143, 6, 46, "Title"],
Cell[1855, 57, 76, 2, 34, "Subtitle"],

Cell[CellGroupData[{
Cell[1956, 63, 25, 0, 53, "Section"],
Cell[1984, 65, 118, 3, 26, "Text"],
Cell[2105, 70, 67, 1, 51, "Input"],
Cell[2175, 73, 67, 1, 51, "Input"],
Cell[2245, 76, 77, 1, 47, "Input"],
Cell[2325, 79, 257, 6, 44, "Text"],
Cell[2585, 87, 82, 1, 47, "Input"],
Cell[2670, 90, 209, 4, 42, "Text"],
Cell[2882, 96, 83, 1, 51, "Input"],
Cell[2968, 99, 64, 0, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3069, 104, 45, 0, 33, "Section"],
Cell[3117, 106, 75, 1, 51, "Input"],
Cell[3195, 109, 555, 17, 60, "Text"],
Cell[3753, 128, 205, 4, 42, "Text"],
Cell[3961, 134, 76, 1, 51, "Input"],
Cell[4040, 137, 83, 1, 53, "Input"],
Cell[4126, 140, 32, 0, 26, "Text"],
Cell[4161, 142, 55, 0, 26, "Text"],
Cell[4219, 144, 69, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4325, 150, 35, 0, 33, "Section"],
Cell[4363, 152, 50, 0, 26, "Text"],
Cell[4416, 154, 100, 2, 47, "Input"],
Cell[4519, 158, 54, 0, 26, "Text"],
Cell[4576, 160, 70, 1, 47, "Input"],
Cell[4649, 163, 208, 4, 42, "Text"],
Cell[4860, 169, 71, 0, 26, "Text"],
Cell[4934, 171, 50, 1, 47, "Input"],
Cell[4987, 174, 250, 6, 43, "Text"],
Cell[5240, 182, 50, 1, 47, "Input"],
Cell[5293, 185, 461, 10, 87, "Text"],

Cell[CellGroupData[{
Cell[5779, 199, 35, 0, 43, "Subsection"],
Cell[5817, 201, 477, 9, 91, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6343, 216, 33, 0, 33, "Section"],
Cell[6379, 218, 242, 5, 58, "Text"],
Cell[6624, 225, 78, 1, 47, "Input"],
Cell[6705, 228, 213, 5, 43, "Text"],
Cell[6921, 235, 60, 1, 49, "Input"],
Cell[6984, 238, 111, 3, 26, "Text"],
Cell[7098, 243, 135, 3, 42, "Text"],
Cell[7236, 248, 73, 1, 47, "Input"],
Cell[7312, 251, 252, 5, 58, "Text"],
Cell[7567, 258, 41, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7645, 264, 26, 0, 33, "Section"],
Cell[7674, 266, 436, 8, 75, "Text"],
Cell[8113, 276, 136, 3, 51, "Input"],
Cell[8252, 281, 83, 1, 47, "Input"],
Cell[8338, 284, 181, 4, 42, "Text"],
Cell[8522, 290, 49, 1, 47, "Input"],
Cell[8574, 293, 115, 3, 26, "Text"],
Cell[8692, 298, 128, 2, 51, "Input"],
Cell[8823, 302, 75, 0, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8935, 307, 35, 0, 33, "Section"],
Cell[8973, 309, 504, 14, 86, "Text"],
Cell[9480, 325, 279, 7, 42, "Text"],
Cell[9762, 334, 473, 6, 90, "Text"],
Cell[10238, 342, 206, 4, 42, "Text"],
Cell[10447, 348, 185, 4, 42, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

